@@ -2,6 +2,7 @@ import pickle
 import datetime
 import pytest
 import six
+import uuid
 from pyrsistent import (
     PRecord, field, InvariantException, ny, pset, PSet, CheckedPVector,
     PTypeError, pset_field, pvector_field, pmap_field, pmap, PMap,
@@ -19,6 +20,10 @@ class RecordContainingContainers(PRecord):
     set = pset_field(str)
 
 
+class UniqueThing(PRecord):
+    id = field(type=uuid.UUID, factory=uuid.UUID)
+
+
 def test_create():
     r = ARecord(x=1, y='foo')
     assert r.x == 1
@@ -150,6 +155,22 @@ def test_initial_value():
     assert a.y == 2
 
 
+def test_enum_field():
+    try:
+        from enum import Enum
+    except ImportError:
+        return  # Enum not supported in this environment
+
+    class TestEnum(Enum):
+        x = 1
+        y = 2
+
+    class RecordContainingEnum(PRecord):
+        enum_field = field(type=TestEnum)
+
+    r = RecordContainingEnum(enum_field=TestEnum.x)
+    assert r.enum_field == TestEnum.x
+
 def test_type_specification_must_be_a_type():
     with pytest.raises(TypeError):
         class BRecord(PRecord):
@@ -752,3 +773,10 @@ def test_supports_lazy_initial_value_for_field():
         a = field(int, initial=lambda: 2)
 
     assert MyRecord() == MyRecord(a=2)
+
+def test_pickle_with_one_way_factory():
+    """
+    A field factory isn't called when restoring from pickle.
+    """
+    thing = UniqueThing(id='25544626-86da-4bce-b6b6-9186c0804d64')
+    assert thing == pickle.loads(pickle.dumps(thing))
